@@ -25,14 +25,13 @@
 
 #include "kmplotprogress.h"
 
-#include <QIcon>
-#include <QPushButton>
-#include <QProgressBar>
 #include <QCoreApplication>
+#include <QDebug>
+#include <QIcon>
+#include <QProgressBar>
+#include <QPushButton>
 #include <QTimer>
 
-#include <kdebug.h>
-
 
 KmPlotProgress::KmPlotProgress( QWidget* parent ) : QWidget( parent )
 {
@@ -69,7 +68,7 @@ void KmPlotProgress::showProgressBar()
 
 void KmPlotProgress::setProgress( double progress )
 {
-	kDebug() << "progress="<<progress;
+	qDebug() << "progress="<<progress;
 
 	Q_ASSERT( progress >= 0 );
 
