@@ -26,11 +26,15 @@
 #include "ui_parameteranimator.h"
 #include "view.h"
 
+#include <KConfigGroup>
+
+#include <QDialogButtonBox>
 #include <QIcon>
 #include <QTimer>
 
 #include <assert.h>
 #include <cmath>
+
 using namespace std;
 
 #ifndef KDEWIN_MATH_H
@@ -52,16 +56,16 @@ class ParameterAnimatorWidget : public QWidget, public Ui::ParameterAnimator
 
 //BEGIN class ParameterAnimator
 ParameterAnimator::ParameterAnimator( QWidget * parent, Function * function )
-	: KDialog( parent ),
+	: QDialog( parent ),
 	m_function( function )
 {
 	m_widget = new ParameterAnimatorWidget( this );
-	m_widget->layout()->setMargin( 0 );
-	setMainWidget( m_widget );
-	
-	setCaption( i18n("Parameter Animator") );
-	setButtons( Close );
-	
+
+	setWindowTitle( i18n("Parameter Animator") );
+	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+	connect(buttonBox, &QDialogButtonBox::rejected, this, &ParameterAnimator::reject);
+	m_widget->layout()->addWidget(buttonBox);
+
 	m_mode = Paused;
 	m_currentValue = 0;
 	m_function->m_parameters.animating = true;
@@ -95,7 +99,7 @@ ParameterAnimator::ParameterAnimator( QWidget * parent, Function * function )
 
 ParameterAnimator::~ ParameterAnimator()
 {
-	kDebug() ;
+	qDebug() ;
 	m_function->m_parameters.animating = false;
 	View::self()->drawPlot();
 }
