@@ -31,7 +31,6 @@
  
 #include <QMap>
 #include <QObject>
-
 #include <QVector>
 
 #include "constants.h"
@@ -161,7 +160,7 @@ struct VectorFunction
 class ExpressionSanitizer
 {
 	public:
-		ExpressionSanitizer( Parser * parent );
+		explicit ExpressionSanitizer( Parser * parent );
 		
 		/**
 		 * Lots of changes to make it happy for the parser (e.g. adding extra
